==> ochusha-0.4.2.1.tar.bz2: ochusha-0.4.2.1/gtk2/marshal.h <==

#ifndef __ochusha_marshal_MARSHAL_H__
#define __ochusha_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:BOOLEAN (marshal.list:1) */
#define ochusha_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN

/* VOID:INT (marshal.list:2) */
#define ochusha_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:POINTER (marshal.list:3) */
#define ochusha_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER

/* VOID:VOID (marshal.list:4) */
#define ochusha_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:ENUM,INT (marshal.list:5) */
extern void ochusha_marshal_VOID__ENUM_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:OBJECT,OBJECT (marshal.list:6) */
extern void ochusha_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:POINTER,BOOLEAN (marshal.list:7) */
extern void ochusha_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:POINTER,POINTER (marshal.list:8) */
extern void ochusha_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:BOXED,POINTER,STRING (marshal.list:9) */
extern void ochusha_marshal_VOID__BOXED_POINTER_STRING (GClosure     *closure,
                                                        GValue       *return_value,
                                                        guint         n_param_values,
                                                        const GValue *param_values,
                                                        gpointer      invocation_hint,
                                                        gpointer      marshal_data);

/* VOID:POINTER,POINTER,POINTER,POINTER (marshal.list:10) */
extern void ochusha_marshal_VOID__POINTER_POINTER_POINTER_POINTER (GClosure     *closure,
                                                                   GValue       *return_value,
                                                                   guint         n_param_values,
                                                                   const GValue *param_values,
                                                                   gpointer      invocation_hint,
                                                                   gpointer      marshal_data);

/* BOOLEAN:POINTER (marshal.list:11) */
extern void ochusha_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* BOOLEAN:BOXED,POINTER,STRING (marshal.list:12) */
extern void ochusha_marshal_BOOLEAN__BOXED_POINTER_STRING (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
                                                           const GValue *param_values,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);

G_END_DECLS

#endif /* __ochusha_marshal_MARSHAL_H__ */

==> ochusha-0.4.3.2.tar.bz2: ochusha-0.4.3.2/gtk2/marshal.h <==

#ifndef __ochusha_marshal_MARSHAL_H__
#define __ochusha_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:BOOLEAN (marshal.list:1) */
#define ochusha_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN

/* VOID:INT (marshal.list:2) */
#define ochusha_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:POINTER (marshal.list:3) */
#define ochusha_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER

/* VOID:VOID (marshal.list:4) */
#define ochusha_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:ENUM,INT (marshal.list:5) */
extern void ochusha_marshal_VOID__ENUM_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:OBJECT,OBJECT (marshal.list:6) */
extern void ochusha_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:POINTER,BOOLEAN (marshal.list:7) */
extern void ochusha_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:POINTER,POINTER (marshal.list:8) */
extern void ochusha_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:BOXED,POINTER,STRING (marshal.list:9) */
extern void ochusha_marshal_VOID__BOXED_POINTER_STRING (GClosure     *closure,
                                                        GValue       *return_value,
                                                        guint         n_param_values,
                                                        const GValue *param_values,
                                                        gpointer      invocation_hint,
                                                        gpointer      marshal_data);

/* VOID:POINTER,POINTER,POINTER,POINTER (marshal.list:10) */
extern void ochusha_marshal_VOID__POINTER_POINTER_POINTER_POINTER (GClosure     *closure,
                                                                   GValue       *return_value,
                                                                   guint         n_param_values,
                                                                   const GValue *param_values,
                                                                   gpointer      invocation_hint,
                                                                   gpointer      marshal_data);

/* BOOLEAN:ENUM,INT (marshal.list:11) */
extern void ochusha_marshal_BOOLEAN__ENUM_INT (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

/* BOOLEAN:POINTER (marshal.list:12) */
extern void ochusha_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* BOOLEAN:BOXED,POINTER,STRING (marshal.list:13) */
extern void ochusha_marshal_BOOLEAN__BOXED_POINTER_STRING (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
                                                           const GValue *param_values,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);

G_END_DECLS

#endif /* __ochusha_marshal_MARSHAL_H__ */
